==> Finance-Python-0.4.1.tar.gz: Finance-Python-0.4.1/PyFin/Math/Accumulators/__init__.py <==
# -*- coding: utf-8 -*-
u"""
Created on 2015-8-8

@author: cheng.li
"""

from PyFin.Math.Accumulators.IAccumulators import TruncatedValueHolder
from PyFin.Math.Accumulators.IAccumulators import Exp
from PyFin.Math.Accumulators.IAccumulators import Log
from PyFin.Math.Accumulators.IAccumulators import Sqrt
from PyFin.Math.Accumulators.IAccumulators import Sign
from PyFin.Math.Accumulators.IAccumulators import Abs
from PyFin.Math.Accumulators.IAccumulators import Pow
from PyFin.Math.Accumulators.IAccumulators import Acos
from PyFin.Math.Accumulators.IAccumulators import Acosh
from PyFin.Math.Accumulators.IAccumulators import Asin
from PyFin.Math.Accumulators.IAccumulators import Asinh

from PyFin.Math.Accumulators.StatelessAccumulators import Latest
from PyFin.Math.Accumulators.StatelessAccumulators import Diff
from PyFin.Math.Accumulators.StatelessAccumulators import SimpleReturn
from PyFin.Math.Accumulators.StatelessAccumulators import LogReturn
from PyFin.Math.Accumulators.StatelessAccumulators import Positive
from PyFin.Math.Accumulators.StatelessAccumulators import Negative
from PyFin.Math.Accumulators.StatelessAccumulators import Max
from PyFin.Math.Accumulators.StatelessAccumulators import Minimum
from PyFin.Math.Accumulators.StatelessAccumulators import Sum
from PyFin.Math.Accumulators.StatelessAccumulators import Average
from PyFin.Math.Accumulators.StatelessAccumulators import XAverage
from PyFin.Math.Accumulators.StatelessAccumulators import Variance
from PyFin.Math.Accumulators.StatelessAccumulators import Correlation
from PyFin.Math.Accumulators.StatelessAccumulators import Product
from PyFin.Math.Accumulators.StatelessAccumulators import CenterMoment
from PyFin.Math.Accumulators.StatelessAccumulators import Skewness
from PyFin.Math.Accumulators.StatelessAccumulators import Kurtosis

from PyFin.Math.Accumulators.StatefulAccumulators import Shift
from PyFin.Math.Accumulators.StatefulAccumulators import MovingAverage
from PyFin.Math.Accumulators.StatefulAccumulators import MovingPositiveAverage
from PyFin.Math.Accumulators.StatefulAccumulators import MovingNegativeAverage
from PyFin.Math.Accumulators.StatefulAccumulators import MovingPositiveDifferenceAverage
from PyFin.Math.Accumulators.StatefulAccumulators import MovingNegativeDifferenceAverage
from PyFin.Math.Accumulators.StatefulAccumulators import MovingRSI
from PyFin.Math.Accumulators.StatefulAccumulators import MovingSum
from PyFin.Math.Accumulators.StatefulAccumulators import MovingCountedPositive
from PyFin.Math.Accumulators.StatefulAccumulators import MovingCountedNegative
from PyFin.Math.Accumulators.StatefulAccumulators import MovingVariance
from PyFin.Math.Accumulators.StatefulAccumulators import MovingNegativeVariance
from PyFin.Math.Accumulators.StatefulAccumulators import MovingCorrelation
from PyFin.Math.Accumulators.StatefulAccumulators import MovingCorrelationMatrix
from PyFin.Math.Accumulators.StatefulAccumulators import MovingMax
from PyFin.Math.Accumulators.StatefulAccumulators import MovingMinimum
from PyFin.Math.Accumulators.StatefulAccumulators import MovingHistoricalWindow
from PyFin.Math.Accumulators.StatefulAccumulators import MovingProduct
from PyFin.Math.Accumulators.StatefulAccumulators import MovingCenterMoment
from PyFin.Math.Accumulators.StatefulAccumulators import MovingSkewness
from PyFin.Math.Accumulators.StatefulAccumulators import MovingTsMaxPos
from PyFin.Math.Accumulators.StatefulAccumulators import MovingTsMinPos
from PyFin.Math.Accumulators.StatefulAccumulators import MovingKurtosis
from PyFin.Math.Accumulators.StatefulAccumulators import MovingRSV
from PyFin.Math.Accumulators.StatefulAccumulators import MACD

from PyFin.Math.Accumulators.Performancers import MovingLogReturn
from PyFin.Math.Accumulators.Performancers import MovingAlphaBeta
from PyFin.Math.Accumulators.Performancers import MovingDrawDown
from PyFin.Math.Accumulators.Performancers import MovingAverageDrawdown
from PyFin.Math.Accumulators.Performancers import MovingMaxDrawdown
from PyFin.Math.Accumulators.Performancers import MovingSharp
from PyFin.Math.Accumulators.Performancers import MovingSortino

__all__ = ["Exp",
           "Log",
           "Sqrt",
           "Sign",
           "Abs",
           "Pow",
           "Acos",
           "Acosh",
           "Asin",
           "Asinh",
           "Latest",
           "Diff",
           "SimpleReturn",
           "LogReturn",
           "Positive",
           "Negative",
           "Max",
           "Minimum",
           "Sum",
           "TruncatedValueHolder",
           "Average",
           "XAverage",
           "MACD",
           "Variance",
           "Correlation",
           "Shift",
           "MovingAverage",
           "MovingPositiveAverage",
           "MovingNegativeAverage",
           "MovingPositiveDifferenceAverage",
           "MovingNegativeDifferenceAverage",
           "MovingRSI",
           "MovingSum",
           "MovingCountedPositive",
           "MovingCountedNegative",
           "MovingNegativeVariance",
           "MovingHistoricalWindow",
           "MovingCorrelation",
           "MovingCorrelationMatrix",
           "MovingMax",
           "MovingMinimum",
           "MovingVariance",
           "MovingLogReturn",
           "MovingAlphaBeta",
           "MovingDrawDown",
           "MovingAverageDrawdown",
           "MovingMaxDrawdown",
           "MovingSharp",
           "MovingSortino",
           "Product",
           "CenterMoment",
           "Skewness",
           "MovingProduct",
           "MovingCenterMoment",
           "MovingSkewness",
           "MovingTsMaxPos",
           "MovingTsMinPos",
           "Kurtosis",
           "MovingKurtosis",
           "MovingRSV"]

==> Finance-Python-0.4.2.tar.gz: Finance-Python-0.4.2/PyFin/Math/Accumulators/__init__.py <==
# -*- coding: utf-8 -*-
u"""
Created on 2015-8-8

@author: cheng.li
"""

from PyFin.Math.Accumulators.IAccumulators import TruncatedValueHolder
from PyFin.Math.Accumulators.IAccumulators import Exp
from PyFin.Math.Accumulators.IAccumulators import Log
from PyFin.Math.Accumulators.IAccumulators import Sqrt
from PyFin.Math.Accumulators.IAccumulators import Sign
from PyFin.Math.Accumulators.IAccumulators import Abs
from PyFin.Math.Accumulators.IAccumulators import Pow
from PyFin.Math.Accumulators.IAccumulators import Acos
from PyFin.Math.Accumulators.IAccumulators import Acosh
from PyFin.Math.Accumulators.IAccumulators import Asin
from PyFin.Math.Accumulators.IAccumulators import Asinh

from PyFin.Math.Accumulators.StatelessAccumulators import Latest
from PyFin.Math.Accumulators.StatelessAccumulators import Diff
from PyFin.Math.Accumulators.StatelessAccumulators import SimpleReturn
from PyFin.Math.Accumulators.StatelessAccumulators import LogReturn
from PyFin.Math.Accumulators.StatelessAccumulators import Positive
from PyFin.Math.Accumulators.StatelessAccumulators import Negative
from PyFin.Math.Accumulators.StatelessAccumulators import Max
from PyFin.Math.Accumulators.StatelessAccumulators import Minimum
from PyFin.Math.Accumulators.StatelessAccumulators import Sum
from PyFin.Math.Accumulators.StatelessAccumulators import Average
from PyFin.Math.Accumulators.StatelessAccumulators import XAverage
from PyFin.Math.Accumulators.StatelessAccumulators import Variance
from PyFin.Math.Accumulators.StatelessAccumulators import Correlation
from PyFin.Math.Accumulators.StatelessAccumulators import Product
from PyFin.Math.Accumulators.StatelessAccumulators import CenterMoment
from PyFin.Math.Accumulators.StatelessAccumulators import Skewness
from PyFin.Math.Accumulators.StatelessAccumulators import Kurtosis
from PyFin.Math.Accumulators.StatelessAccumulators import Rank
from PyFin.Math.Accumulators.StatelessAccumulators import LevelList
from PyFin.Math.Accumulators.StatelessAccumulators import LevelValue
from PyFin.Math.Accumulators.StatelessAccumulators import AutoCorrelation

from PyFin.Math.Accumulators.StatefulAccumulators import Shift
from PyFin.Math.Accumulators.StatefulAccumulators import MovingAverage
from PyFin.Math.Accumulators.StatefulAccumulators import MovingPositiveAverage
from PyFin.Math.Accumulators.StatefulAccumulators import MovingNegativeAverage
from PyFin.Math.Accumulators.StatefulAccumulators import MovingPositiveDifferenceAverage
from PyFin.Math.Accumulators.StatefulAccumulators import MovingNegativeDifferenceAverage
from PyFin.Math.Accumulators.StatefulAccumulators import MovingRSI
from PyFin.Math.Accumulators.StatefulAccumulators import MovingSum
from PyFin.Math.Accumulators.StatefulAccumulators import MovingCountedPositive
from PyFin.Math.Accumulators.StatefulAccumulators import MovingCountedNegative
from PyFin.Math.Accumulators.StatefulAccumulators import MovingVariance
from PyFin.Math.Accumulators.StatefulAccumulators import MovingNegativeVariance
from PyFin.Math.Accumulators.StatefulAccumulators import MovingCorrelation
from PyFin.Math.Accumulators.StatefulAccumulators import MovingCorrelationMatrix
from PyFin.Math.Accumulators.StatefulAccumulators import MovingMax
from PyFin.Math.Accumulators.StatefulAccumulators import MovingMinimum
from PyFin.Math.Accumulators.StatefulAccumulators import MovingHistoricalWindow
from PyFin.Math.Accumulators.StatefulAccumulators import MovingProduct
from PyFin.Math.Accumulators.StatefulAccumulators import MovingCenterMoment
from PyFin.Math.Accumulators.StatefulAccumulators import MovingSkewness
from PyFin.Math.Accumulators.StatefulAccumulators import MovingMaxPos
from PyFin.Math.Accumulators.StatefulAccumulators import MovingMinPos
from PyFin.Math.Accumulators.StatefulAccumulators import MovingKurtosis
from PyFin.Math.Accumulators.StatefulAccumulators import MovingRSV
from PyFin.Math.Accumulators.StatefulAccumulators import MACD
from PyFin.Math.Accumulators.StatefulAccumulators import MovingRank
from PyFin.Math.Accumulators.StatefulAccumulators import MovingKDJ
from PyFin.Math.Accumulators.StatefulAccumulators import MovingLevel
from PyFin.Math.Accumulators.StatefulAccumulators import MovingAroon
from PyFin.Math.Accumulators.StatefulAccumulators import MovingBias
from PyFin.Math.Accumulators.StatefulAccumulators import MovingAutoCorrelation

from PyFin.Math.Accumulators.Performancers import MovingLogReturn
from PyFin.Math.Accumulators.Performancers import MovingAlphaBeta
from PyFin.Math.Accumulators.Performancers import MovingDrawDown
from PyFin.Math.Accumulators.Performancers import MovingAverageDrawdown
from PyFin.Math.Accumulators.Performancers import MovingMaxDrawdown
from PyFin.Math.Accumulators.Performancers import MovingSharp
from PyFin.Math.Accumulators.Performancers import MovingSortino

__all__ = ["Exp",
           "Log",
           "Sqrt",
           "Sign",
           "Abs",
           "Pow",
           "Acos",
           "Acosh",
           "Asin",
           "Asinh",
           "Latest",
           "Diff",
           "SimpleReturn",
           "LogReturn",
           "Positive",
           "Negative",
           "Max",
           "Minimum",
           "Sum",
           "TruncatedValueHolder",
           "Average",
           "XAverage",
           "MACD",
           "Variance",
           "Correlation",
           "Shift",
           "MovingAverage",
           "MovingPositiveAverage",
           "MovingNegativeAverage",
           "MovingPositiveDifferenceAverage",
           "MovingNegativeDifferenceAverage",
           "MovingRSI",
           "MovingSum",
           "MovingCountedPositive",
           "MovingCountedNegative",
           "MovingNegativeVariance",
           "MovingHistoricalWindow",
           "MovingCorrelation",
           "MovingCorrelationMatrix",
           "MovingMax",
           "MovingMinimum",
           "MovingVariance",
           "MovingLogReturn",
           "MovingAlphaBeta",
           "MovingDrawDown",
           "MovingAverageDrawdown",
           "MovingMaxDrawdown",
           "MovingSharp",
           "MovingSortino",
           "Product",
           "CenterMoment",
           "Skewness",
           "MovingProduct",
           "MovingCenterMoment",
           "MovingSkewness",
           "MovingMaxPos",
           "MovingMinPos",
           "Kurtosis",
           "MovingKurtosis",
           "MovingRSV",
           "MovingRank",
           "Rank",
           "MovingKDJ",
           "MovingAroon",
           "MovingBias",
           "MovingLevel",
           "LevelValue",
           "LevelList",
           "AutoCorrelation",
           "MovingAutoCorrelation"]
